import React, { FC, ReactNode } from 'react';
import { Button } from 'react-native-ui-xep';
import {
  ModalProps,
  Modal as ModalX,
  StatusBar,
  View,
  ScrollView,
} from 'react-native';
import { Text } from 'native-base';
import { ButtonTypeProps } from '../button/Button';
import { styles } from './styles';

type Props = ModalProps & {
  title: string;
  type?: 'custom' | 'customContent';
  message?: string;
  text?: string;
  titleProps?: any;
  textProps?: any;
  buttonText: string;
  buttonType?: ButtonTypeProps;
  onButtonConfirm?: () => void;
  hideDivider?: boolean;
  close?: any;
  children?: ReactNode;
};

export const Modal: FC<Props> = (props: Props) => {
  const {
    children,
    close,
    text,
    title,
    titleProps,
    textProps,
    buttonType,
    buttonText,
    onButtonConfirm,
    hideDivider,
    type,
  } = props;
  const renderModalDefault = (titleStyle?: object, textStyle?: object) => {
    return (
      <ModalX
        animationType="slide"
        transparent={true}
        // visible={visible}
        onRequestClose={close}
        {...props}
      >
        <StatusBar translucent backgroundColor="rgba(0, 0, 0, 0.5)" />
        <View style={styles.centeredView}>
          <View style={styles.modalView}>
            <ScrollView>
              <Text
                style={
                  titleProps?.style !== undefined
                    ? { ...titleStyle, ...(titleProps?.style as object) }
                    : titleStyle
                }
              >
                {title}
              </Text>
              {(hideDivider === undefined || !hideDivider) && (
                <View style={styles.horizontalLine} />
              )}
              <Text
                style={
                  textProps?.style !== undefined
                    ? { ...textStyle, ...(textProps?.style as object) }
                    : textStyle
                }
              >
                {text}
              </Text>
              <Button
                type={buttonType}
                style={styles.button}
                onPress={onButtonConfirm}
              >
                {buttonText ?? 'Return'}
              </Button>
              {children}
            </ScrollView>
          </View>
        </View>
      </ModalX>
    );
  };
  const renderModelCustomContent = (titleStyle?: object) => {
    return (
      <ModalX
        animationType="slide"
        transparent={true}
        // visible={visible}
        onRequestClose={close}
        {...props}
      >
        <StatusBar translucent backgroundColor="rgba(0, 0, 0, 0.5)" />
        <View style={styles.centeredView}>
          <View style={styles.modalView}>
            <ScrollView>
              <Text
                style={
                  titleProps?.style !== undefined
                    ? { ...titleStyle, ...(titleProps?.style as object) }
                    : titleStyle
                }
              >
                {title}
              </Text>
              {(hideDivider === undefined || !hideDivider) && (
                <View style={styles.horizontalLine} />
              )}
              {children}
              <Button
                type={buttonType}
                style={styles.button}
                onPress={onButtonConfirm}
              >
                {buttonText ?? 'Return'}
              </Button>
            </ScrollView>
          </View>
        </View>
      </ModalX>
    );
  };
  switch (type) {
    case 'custom':
      return (
        <ModalX animationType="slide" transparent={true} {...props}>
          <StatusBar translucent backgroundColor="rgba(0, 0, 0, 0.5)" />
          <View style={styles.centeredView}>
            <View style={styles.modalView}>{children}</View>
          </View>
        </ModalX>
      );
    case 'customContent':
      return renderModelCustomContent(styles.defaultTitle);
    default:
      return renderModalDefault(styles.defaultTitle, styles.defaultText);
  }
};
